@@ -5,7 +5,7 @@ MAINNET_ADDRESSES = {
     "PriceAggregator": "0x64e2625621970F8cfA17B294670d61CB883dA511",
     "USDC": "0x833589fCD6eDb6E08f4c7C32D4f71b54bdA02913",
     "Trading": "0x44914408af82bC9983bbb330e3578E1105e11d4e",
-    "Multicall": "0x7A829c5C97A2Bf8BeFB4b01d96A282E4763848d8",
+    "Multicall": "0xA7cFc43872F4D7B0E6141ee8c36f1F7FEe5d099e",
     "Referral": "0x1A110bBA13A1f16cCa4b79758BD39290f29De82D",
 }
 
